@@ -59,6 +59,18 @@ pub struct Opts {
     /// Minify javascript assets with swc. Applies to release builds only.
     #[arg(long, default_value = "true", value_parser=clap::builder::BoolishValueParser::new(), action = clap::ArgAction::Set)]
     pub js_minify: bool,
+
+    /// Split WASM binary based on #[lazy] macros.
+    #[arg(long)]
+    pub split: bool,
+
+    /// Only build the frontend.
+    #[arg(long)]
+    pub frontend_only: bool,
+
+    /// Only build the server.
+    #[arg(long, conflicts_with="frontend_only")]
+    pub server_only: bool,
 }
 
 #[derive(Debug, Clone, Parser, PartialEq, Default)]
